=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2006-02-14 18:36:30 +0000
+++ bzrlib/gpg.py	2006-02-15 15:18:44 +0000
@@ -19,11 +19,9 @@
 
 import errno
 import subprocess
-import tempfile
 
 import bzrlib.errors as errors
 
-
 class DisabledGPGStrategy(object):
     """A GPG Strategy that makes everything fail."""
 
@@ -48,30 +46,26 @@
     """GPG Signing and checking facilities."""
         
     def _command_line(self):
-        return [self._config.gpg_signing_command(),
-                '--output', '-', '--clearsign']
+        return [self._config.gpg_signing_command(), '--clearsign']
 
     def __init__(self, config):
         self._config = config
 
     def sign(self, content):
-        f = tempfile.NamedTemporaryFile()
-        cmd = self._command_line() + [f.name]
-        f.write(content)
-        f.flush()
         try:
-            process = subprocess.Popen(cmd,
+            process = subprocess.Popen(self._command_line(),
+                                       stdin=subprocess.PIPE,
                                        stdout=subprocess.PIPE)
             try:
-                result = process.communicate()[0]
+                result = process.communicate(content)[0]
                 if process.returncode is None:
                     process.wait()
                 if process.returncode != 0:
-                    raise errors.SigningFailed(cmd)
+                    raise errors.SigningFailed(self._command_line())
                 return result
             except OSError, e:
                 if e.errno == errno.EPIPE:
-                    raise errors.SigningFailed(cmd)
+                    raise errors.SigningFailed(self._command_line())
                 else:
                     raise
         except ValueError:
@@ -80,7 +74,6 @@
         except OSError, e:
             if e.errno == errno.ENOENT:
                 # gpg is not installed
-                raise errors.SigningFailed(cmd)
+                raise errors.SigningFailed(self._command_line())
             else:
                 raise
-        f.close()

=== modified file 'bzrlib/tests/test_gpg.py'
--- bzrlib/tests/test_gpg.py	2006-02-14 18:36:30 +0000
+++ bzrlib/tests/test_gpg.py	2006-02-15 15:18:44 +0000
@@ -35,7 +35,7 @@
 
     def test_signing_command_line(self):
         my_gpg = gpg.GPGStrategy(FakeConfig())
-        self.assertEqual(['false',  '--output', '-', '--clearsign'],
+        self.assertEqual(['false',  '--clearsign'],
                          my_gpg._command_line())
 
     def test_checks_return_code(self):
@@ -56,12 +56,12 @@
             # It is too much work to make sys.stdout be in binary mode.
             # http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/65443
             my_gpg._command_line = lambda:[sys.executable, '-c',
-                    'import sys; sys.stdout.write(open(sys.argv[-1].read()))']
+                    'import sys; sys.stdout.write(sys.stdin.read())']
             new_content = content.replace('\n', '\r\n')
 
             self.assertEqual(new_content, my_gpg.sign(content))
         else:
-            my_gpg._command_line = lambda:['cat']
+            my_gpg._command_line = lambda:['cat', '-']
             self.assertEqual(content, my_gpg.sign(content))
 
 

